@@ -66,7 +66,7 @@ import pyembroidery.Vp3Writer as Vp3Writer
 import pyembroidery.XxxReader as XxxReader
 import pyembroidery.XxxWriter as XxxWriter
 
-# import pyembroidery.ZhsReader as ZhsReader
+import pyembroidery.ZhsReader as ZhsReader
 import pyembroidery.ZxyReader as ZxyReader
 
 from .EmbEncoder import Transcoder as Normalizer
@@ -523,7 +523,7 @@ class EmbPattern:
         if position < 0:
             position += len(self.stitches)  # I need positive positions.
         if position == 0:
-            self.stitches.insert(0, [dx, dy, TRIM])  # started (0,0)
+            self.stitches.insert(0, [dx, dy, cmd])  # started (0,0)
         elif (
             position == len(self.stitches) or position is None
         ):  # This is properly just an add.
@@ -532,7 +532,7 @@ class EmbPattern:
             p = self.stitches[position - 1]
             x = p[0] + dx
             y = p[1] + dy
-            self.stitches.insert(position, [x, y, TRIM])
+            self.stitches.insert(position, [x, y, cmd])
 
     def insert(self, position, cmd, x=0, y=0):
         """Insert a stitch or command"""
@@ -923,7 +923,7 @@ class EmbPattern:
         )
         yield (
             {
-                "description": "Melco Embroidery Format",
+                "description": "Melco Expanded Embroidery Format",
                 "extension": "exp",
                 "extensions": ("exp",),
                 "mimetype": "application/x-exp",
@@ -932,6 +932,16 @@ class EmbPattern:
                 "writer": ExpWriter,
             }
         )
+        # yield (
+        #     {
+        #         "description": "Melco Condensed Embroidery Format",
+        #         "extension": "cnd",
+        #         "extensions": ("cnd",),
+        #         "mimetype": "application/x-cnd",
+        #         "category": "embroidery",
+        #         "reader": CndReader,
+        #     }
+        # )
         yield (
             {
                 "description": "Tajima Embroidery Format",
@@ -1317,13 +1327,13 @@ class EmbPattern:
                 "reader": StcReader,
             }
         )
-        # yield ({
-        #     "description": "Zeng Hsing Embroidery Format",
-        #     "extension": "zhs",
-        #     "mimetype": "application/x-zhs",
-        #     "category": "embroidery",
-        #     "reader": ZhsReader
-        # })
+        yield ({
+            "description": "Zeng Hsing Embroidery Format",
+            "extension": "zhs",
+            "mimetype": "application/x-zhs",
+            "category": "embroidery",
+            "reader": ZhsReader
+        })
         yield (
             {
                 "description": "ZSK TC Embroidery Format",
